import React, { createContext, useMemo } from 'react';

export const ElectronContext = createContext<Window['electron'] | null>(null);
ElectronContext.displayName = 'ElectronContext';

interface ElectronProviderProps {
  children: React.ReactNode;
}

export const ElectronProvider: React.FC<ElectronProviderProps> = ({ children }) => {
  const electronApi = useMemo(() => {
    if (typeof window === 'undefined' || !window.electron) {
      console.error('Electron API not found in window object');
      return null;
    }
    return window.electron;
  }, []);

  return (
    <ElectronContext.Provider value={electronApi}>
      {children}
    </ElectronContext.Provider>
  );
};
