import { useState, useEffect } from 'react';
import { useElectron } from './useElectron';
import type { LLMConfig } from '../../electron/types';

export function useLLMConfig() {
  const electron = useElectron();
  const [config, setConfig] = useState<LLMConfig | null>(null);
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    loadConfig();
  }, []);

  const loadConfig = async () => {
    try {
      setIsLoading(true);
      setError(null);
      const config = await electron.getLLMConfig();
      setConfig(config);
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Failed to load LLM config');
      console.error('Error loading LLM config:', err);
    } finally {
      setIsLoading(false);
    }
  };

  return {
    config,
    isLoading,
    error,
  };
}
