import { useState, useEffect } from 'react';
import { useElectron } from './useElectron';

export function useOllamaModels() {
  const electron = useElectron();
  const [models, setModels] = useState<string[]>([]);
  const [isLoading, setIsLoading] = useState(true);
  const [error, setError] = useState<string | null>(null);

  useEffect(() => {
    loadModels();
  }, []);

  const loadModels = async () => {
    try {
      setIsLoading(true);
      setError(null);
      const response = await electron.getOllamaModels();
      if (response.success) {
        setModels(response.data || []);
      } else {
        throw new Error(response.error);
      }
    } catch (err) {
      setError(err instanceof Error ? err.message : 'Failed to load Ollama models');
      console.error('Error loading Ollama models:', err);
    } finally {
      setIsLoading(false);
    }
  };

  return {
    models,
    isLoading,
    error,
    reloadModels: loadModels,
  };
}
